import test from "ava"
import {
  buildAndSnapshotFilesystem,
  createSourceFiles,
  createPackage,
  cleanFiles,
} from "../helpers/filesystem"

test.beforeEach((t) => cleanFiles())
test.after.always((t) => cleanFiles())

test("transpiles stylesheets using Stage 2 features", async (t) => {
  await buildAndSnapshotFilesystem(t, async () => {
    await createSourceFiles({
      "index.css": `
        body {
          font-family: system-ui;
        }
      `,
    })
  })
})

test("transpiles stylesheets using thee custom-media-queries feature from Stage 1", async (t) => {
  await buildAndSnapshotFilesystem(t, async () => {
    await createSourceFiles({
      "index.css": `
        @custom-media --small-viewport (max-width: 30em);

        @media (--small-viewport) {
          nav {
            display: none;
          }
        }
      `,
    })
  })
})

test("inlines stylesheets with relative @import statements to current directory", async (t) => {
  await buildAndSnapshotFilesystem(t, async () => {
    await createSourceFiles({
      "other.css": `
        p {
          color: red;
        }
      `,
      "index.css": `
        @import "./other.css";

        a {
          color: black;
        }
      `,
    })
  })
})

test("inlines stylesheets with relative @import statements to parent directory", async (t) => {
  await buildAndSnapshotFilesystem(t, async () => {
    await createSourceFiles({
      "other.css": `
        p {
          color: red;
        }
      `,
      "folder/index.css": `
        @import "../other.css";

        a {
          color: black;
        }
      `,
    })
  })
})

test("inlines stylesheets from npm packages", async (t) => {
  await buildAndSnapshotFilesystem(t, async () => {
    await createPackage("foo", {
      "index.css": `
        p {
          color: red;
        }
      `,
    })

    await createSourceFiles({
      "index.css": `
        @import "foo";

        a {
          color: black;
        }
      `,
    })
  })
})
